Module seagul_core::encoder [−][src]
The module holding all the encoders
Structs
| ColorChange | Describes a color change to a set of coordinates (0, 1) from (2) to (3) |
| EncodeMap | Describes how a single byte is encoded |
| EncodedImage | Represents the result of an image encoded with |
| ImageEncoder | An image decoder takes an image and alters its pixels to encode arbitrary data |